@@ -1,7 +1,7 @@
 package CPANPLUS::YACSmoke;
-$CPANPLUS::YACSmoke::VERSION = '1.03_01'; # TRIAL
+$CPANPLUS::YACSmoke::VERSION = '1.03_02'; # TRIAL
 
-$CPANPLUS::YACSmoke::VERSION = '1.0301';# Dist::Zilla: +PodWeaver
+$CPANPLUS::YACSmoke::VERSION = '1.0302';# Dist::Zilla: +PodWeaver
 #ABSTRACT: Yet Another CPANPLUS Smoke Tester
 
 use strict;
@@ -171,7 +171,7 @@ sub test {
 		CPANPLUS::Error->flush();
 		my $stat = $self->{cpanplus}->install(
 				modules  => [ $mod ],
-				target   => 'create',
+				target   => $target,
 				allow_build_interactively => 0,
 				# other settings now set via set_config() method
 		);
@@ -473,7 +473,7 @@ CPANPLUS::YACSmoke - Yet Another CPANPLUS Smoke Tester
 
 =head1 VERSION
 
-version 1.03_01
+version 1.03_02
 
 =head1 SYNOPSIS
 
